@@ -129,7 +129,9 @@ def get_tab(self):
         model_data = pop.history
         t = range(len(model_data))
         if self.cumul_reset:
-            cumul_offset = pop.history[range_list[0]]
+            cumul_offset = 0
+            if pop.monotonic:
+                cumul_offset = pop.history[range_list[0]]
             model_data = [pop.history[i] - cumul_offset for i in range(range_list[0],range_list[1])]
             t = range(range_list[0], range_list[1])
 
@@ -138,7 +140,9 @@ def get_tab(self):
         td = range(range_list[0], range_list[1])
         data = []
         if self.cumul_reset:
-            cumul_offset = self.pop_data[self.full_pop_name][range_list[0]]
+            cumul_offset = 0
+            if pop.monotonic:
+                cumul_offset = self.pop_data[self.full_pop_name][range_list[0]]
             for i in td:
                 data.append(self.pop_data[self.full_pop_name][i] - cumul_offset)
         else:
@@ -238,7 +242,7 @@ def get_tab(self):
                                         description='Skip days:', disabled=False,
                                         continuous_update=False)
 
-    self.cumul_reset_checkbox = widgets.Checkbox(value=self.cumul_reset, description='start cumulative at 0', disabled=False)
+    self.cumul_reset_checkbox = widgets.Checkbox(value=self.cumul_reset, description='start cumulative at 0 (local)', disabled=False)
     def cumul_reset_eventhandler(change):
         self.cumul_reset = self.cumul_reset_checkbox.value
     self.cumul_reset_checkbox.observe(cumul_reset_eventhandler, names='value')
@@ -453,6 +457,10 @@ def get_tab(self):
                     check_trans_button.disabled = False
                     mod_trans_button.disabled = False
                     with output:
+                        if self.cumul_reset:
+                            print('Local fit. Iterations start at step:',self.optimizer.start_step)
+                            print(' ')
+
                         print('Fit results:')
                         for par_name in self.optimizer.variable_names:
                             print('  '+par_name,'= {0:0.3f}'.format(self.model.parameters[par_name].get_value()))
