@@ -59,7 +59,7 @@ class ipypm:
         self.model_filenames = None
         self.region_data_folders = None
         self.data_fit_statistics = None
-        self.cumul_reset = False
+        self.cumul_reset = True
         self.cumul_reset_checkbox = None
         self.mod_last_transition = None
         self.mod_alphas_std = None
@@ -79,7 +79,7 @@ class ipypm:
         n_days = (date.today() - self.model_t0.value).days
         n_days = n_days - n_days % 10 + 10
         self.n_days_widget = widgets.BoundedIntText(
-            value=n_days, min=10, max=500, step=1, description='n_days:',
+            value=n_days, min=10, max=700, step=1, description='n_days:',
             tooltip='number of days to model: sets the upper time range of plots')
         # Compare A and B
         self.model_names = [widgets.Text(value='', description='Model A:', disabled=True),
